@@ -86,7 +86,7 @@
 #define KNEWSTUFFCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNEWSTUFFCORE_NO_DEPRECATED
-#  define KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56500
 #endif
 #ifdef KNEWSTUFFCORE_NO_DEPRECATED_WARNINGS
 #  define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0x56500
 #  endif
 #endif
 
@@ -216,7 +216,7 @@
 #define KNEWSTUFFCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNEWSTUFFCORE_NO_DEPRECATED
-#  define KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56500
 #endif
 #ifdef KNEWSTUFFCORE_NO_DEPRECATED_WARNINGS
 #  define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -226,7 +226,7 @@
 #  ifdef KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0x56500
 #  endif
 #endif
 
